SHARED_TESTING_CONFIG = {
    "adapters_manager": {"adapters": {}},
    "attrs_cfg_path": "mock_path",
    "perun_person_principal_names_attribute": "mock_name",
}
ATTRS_MAP = {}
